@@ -19,7 +19,7 @@ import importlib
 list_module = ["clean", "gen_pid", \
                "sid_pid_file", "gen_sid", "func", "api_types", \
                'system_update', 'request', 'certificate', 'edit_groups',
-               "setup_package"]
+               "setup_package", "set_vars"]
 
 imported_modules = []
 pack = "calculate.core.server"
