@@ -45,7 +45,7 @@ class replaceClass():
         if "LANG" in os.environ:
             curThread = threading.currentThread()
             curThread.lang = os.environ["LANG"]
-        com = target(self.no_progress,self.gui_progress,self.gui_warning)
+        com = target(self.no_progress,self.gui_progress,self.gui_warning,self.no_questions)
         if len(com.__class__.__bases__)>1 and \
             hasattr (com.__class__.__bases__[1], '__init__'):
             com.__class__.__bases__[1].__init__(com)
@@ -55,7 +55,7 @@ class replaceClass():
     class Common(CommonMethods):
         """ class to interact with the processes """
         reClearTags = re.compile("<.*?>")
-        def __init__(self, no_progress, gui_progress,gui_warning):
+        def __init__(self, no_progress, gui_progress,gui_warning,no_questions):
             self.pid = 0
             self.Num = 100000
             self.color_print = color_print()
@@ -68,6 +68,7 @@ class replaceClass():
             self.last_progress_msg = ''
             self.error = []
             self.warning = []
+            self.no_questions = no_questions
 
         def writeFile(self):
             pass
@@ -279,9 +280,11 @@ class replaceClass():
                 self.color_print.printOK(self.clearTags(result))
             self.setProgress(100, progress_message)
 
-        def askConfirm(self,message):
+        def askConfirm(self,message,default="yes"):
             colorPrint = color_print()
             print
+            if self.no_questions:
+                return default
             while True:
                 try:
                     ask = raw_input(message+ '? (yes/no): ')
@@ -289,11 +292,17 @@ class replaceClass():
                     ask = 'no'
                     print
                 if ask.lower() in ['n', 'no']:
-                    colorPrint.printERROR(_('Manually interrupted'))
+                    #colorPrint.printERROR(_('Manually interrupted'))
                     return "no"
                 if ask.lower() in ['y', 'yes']:
                     return "yes"
 
+        def isInteractive(self):
+            """
+            Check interactive ability
+            """
+            return sys.stdin.isatty()
+
         def askChoice(self,message,answers=[("yes","Yes"),("no","No")]):
             colorPrint = color_print()
             print
@@ -468,13 +477,13 @@ def call_method(metaObject, args, unknown_args, colorPrint):
     metaObject.no_progress = args.no_progress
     metaObject.gui_progress = args.gui_progress
     metaObject.gui_warning = args.gui_warning
+    metaObject.no_questions = False
     view_obj = ViewInfo()
     view_obj.step = None
     view_obj.expert = True
     view_obj.brief = None
     view_obj.onlyhelp = False
 
-    no_questions = args.no_questions
     try:
         view = getattr(metaObject, method_view_name)(0, view_obj)
     except AttributeError:
@@ -483,7 +492,10 @@ def call_method(metaObject, args, unknown_args, colorPrint):
     method_parser = get_method_argparser(view, args, cl_core = True)
     param_object = create_param_object(view)
     try:
+        unknown_args = method_parser.fixBoolVariables(unknown_args)
         args, unknown_args = method_parser.parse_known_args(unknown_args)
+        no_questions = args.no_questions
+        metaObject.no_questions = no_questions
     except SystemExit as e:
         return 1
     except Exception as e:
@@ -752,7 +764,7 @@ class Methods(replaceClass.Common,object):
         return cls._instance
 
     def __init__(self):
-        replaceClass.Common.__init__(self,True,False,False)
+        replaceClass.Common.__init__(self,True,False,False,False)
 
 def printTable(data, header=None):
     try:
