@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 
-__version__ = "3.1.0"
+__version__ = "3.1.4"
 __app__ = "calculate-core"
 
 import sys, os
@@ -404,7 +404,8 @@ class updateSystemConfigs(shareUpdateConfigs):
                            printWARNING=self.printWARNING,
                            askConfirm=self.askConfirm,
                            dispatchConf= self.dispatchConf
-                                if not clVars.Get('cl_ebuild_phase') else None,
+                                if not clVars.Get('cl_ebuild_phase') and \
+                                    self.isInteractive() else None,
                            printWarning=False)
         clTempl.onFirstValue = lambda *args: \
             self.startTask(_("System configuring for {nameProgram} package by "
@@ -478,6 +479,33 @@ class PackageUpdater(updateSystemConfigs,updateUserConfigs):
         self.closeClTemplate()
         return True
 
+    @safetyWrapper(native_errors=(cl_template.TemplatesError,),
+                   man_int=__("Manually interrupted"),
+                   post_action=postAction)
+    def patchPackage(self,dv):
+        self.initVars(dv)
+        configPath = dv.Get('cl_core_pkg_path')
+        dv.Set("cl_root_path", configPath, True)
+        clTempl = ChainProgressTemplate( self.startTask,
+                           self.endTask,
+                           self.setProgress,
+                           self.clVars, cltObj = False,
+                           printSUCCESS=self.printSUCCESS,
+                           printERROR=self.printERROR,
+                           askConfirm=self.askConfirm,
+                           printWARNING=self.printWARNING,
+                           printWarning=False)
+        nameProgram = self.clVars.Get('cl_core_pkg_name')
+        clTempl.onFirstValue = lambda *args: \
+                self.startTask(
+                    _("Using patches for the {nameProgram} package by "
+                      "Calculate Utilities").format(
+                      nameProgram=nameProgram),
+                      progress=True)
+        dirsFiles = clTempl.applyTemplates()
+        return True
+
+
     @safetyWrapper(native_errors=(cl_template.TemplatesError,),
                    man_int=__("Manually interrupted"),
                    post_action=postAction)
@@ -611,3 +639,37 @@ class CoreWsdl:
     @rpc(Integer, ViewParams,_returns = ViewInfo)
     def core_dispatch_view (self, sid, params):
         return ViewInfo()
+
+    @rpc(Integer, CoreSetupInfo, _returns = Array(ReturnedMessage))
+    @core_method(category=__('Configuration'),title=__('Patch'),
+        image='system-run,system,computer',command="cl-core-patch",
+        gui=False, rights=['setup'])
+    def core_patch ( self, sid, info):
+        return self.callMethod(sid,info,logicClass=PackageUpdater,
+                           method="patchPackage",method_name="core_patch")
+
+    def core_patch_vars(self,dv=None):
+        if not dv:
+            dv = DataVarsCore()
+            dv.importCore()
+            dv.flIniFile()
+            dv.Set('cl_action','patch',True)
+            dv.Set('cl_dispatch_conf','usenew',True)
+        dv.addGroup(None,
+            normal=('cl_core_pkg_name',),
+            expert=('cl_core_pkg_category', 'cl_core_pkg_version',
+                    'cl_core_pkg_slot', 'cl_core_pkg_path',
+                    'cl_templates_locate','cl_verbose_set'),
+            next_label=_("Patch"))
+        return dv
+
+    @rpc(Integer, ViewParams,_returns = ViewInfo)
+    def core_patch_view (self, sid, params):
+        dv = self.get_cache(sid,"core_patch","vars")
+        if not dv:
+            dv = self.core_patch_vars()
+        else:
+            dv.processRefresh()
+        view = ViewInfo(dv,viewparams=params)
+        self.set_cache(sid, 'core_patch', "vars",dv,smart=False)
+        return view
