@@ -14,25 +14,11 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from calculate.lib.datavars import ReadonlyVariable
-from calculate.core.datavars import __version__,__app__
-
 import core
 import request
 import certificate
 import edit_groups
 import setup_package
+import variable
 
 section = "core"
-
-class VariableClName(ReadonlyVariable):
-    """
-    Package name
-    """
-    value = __app__
-
-class VariableClVer(ReadonlyVariable):
-    """
-    Package version
-    """
-    value = __version__
